@@ -35,16 +35,16 @@ def run_devserver(config, root):
     
     cmd = silk.lib.get_gunicorn_cmd(config)
     
-    env = {
+    subproc_env = {
         'SILK_ROOT': root,
         'SILK_ROLE': silk.lib.get_role(),
     }
 
-    # By adding our current environment to that used for the subprocess, we
-    # ensure that the same paths will be used (such as those set by virtualenv)
-    env.update(os.environ)
+    # By adding our current subproc_environment to that used for the subprocess, we
+    # ensure that the same paths will be used (such as those set by virtualsubproc_env)
+    subproc_env.update(os.environ)
 
-    run_til_you_die(cmd.split(), SIGINT, cwd=root, env=env)
+    run_til_you_die(cmd.split(), SIGINT, cwd=root, env=subproc_env)
 
     # This 1 second sleep lets the gunicorn workers exit before we show the
     # prompt again.
